@@ -1,7 +1,7 @@
 <?php
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2017 The Cacti Group                                 |
+ | Copyright (C) 2004-2018 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU General Public License             |
@@ -203,7 +203,7 @@ function api_device_save($id, $host_template_id, $description, $hostname, $snmp_
 		$save['snmp_context']         = form_input_validate($snmp_context, 'snmp_context', '', true, 3);
 		$save['snmp_engine_id']       = form_input_validate($snmp_engine_id, 'snmp_engine_id', '', true, 3);
 
-		if (strlen($save['snmp_password']) < 8) {
+		if (strlen($save['snmp_password']) < 8 && $snmp_auth_protocol != '[None]') {
 			raise_message(32);
 			$_SESSION['sess_error_fields']['snmp_password'] = 'snmp_password';
 		}
@@ -392,8 +392,19 @@ function api_device_ping_device($device_id, $from_remote = false) {
 	$anym = false;
 
 	if ($config['poller_id'] != $host['poller_id'] && $from_remote == false) {
-		$hostname = db_fetch_cell_prepared('SELECT hostname FROM poller WHERE id = ?', array($host['poller_id']));
-		print file_get_contents(get_url_type() .'://' . $hostname . $config['url_path'] . 'remote_agent.php?action=ping&host_id=' . $host['id']);
+		$hostname = db_fetch_cell_prepared('SELECT hostname
+			FROM poller
+			WHERE id = ?',
+			array($host['poller_id']));
+		
+		$fgc_contextoption = get_default_contextoption();
+		if($fgc_contextoption) {
+			$fgc_context = stream_context_create($fgc_contextoption);
+			print file_get_contents(get_url_type() .'://' . $hostname . $config['url_path'] . 'remote_agent.php?action=ping&host_id=' . $host['id'], false, $fgc_context);
+		} else {
+			print file_get_contents(get_url_type() .'://' . $hostname . $config['url_path'] . 'remote_agent.php?action=ping&host_id=' . $host['id']);
+		}
+
 		return;
 	}
 
