@@ -2,7 +2,7 @@
 
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2017 The Cacti Group                                 |
+ | Copyright (C) 2004-2018 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU General Public License             |
@@ -14,7 +14,7 @@
  | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the           |
  | GNU General Public License for more details.                            |
  +-------------------------------------------------------------------------+
- | Cacti: The Complete RRDTool-based Graphing Solution                     |
+ | Cacti: The Complete RRDtool-based Graphing Solution                     |
  +-------------------------------------------------------------------------+
  | This code is designed, written, and maintained by the Cacti Group. See  |
  | about.php and/or the AUTHORS file for specific developer information.   |
@@ -335,7 +335,7 @@ function list_rrd() {
 		$sql_order
 		$sql_limit");
 
-	$nav = html_nav_bar($config['url_path'] . 'rrdcleaner.php?filter'. get_request_var('filter'), MAX_DISPLAY_PAGES, get_request_var('page'), $rows, $total_rows, 8, 'RRD Files', 'page', 'main');
+	$nav = html_nav_bar($config['url_path'] . 'rrdcleaner.php?filter'. get_request_var('filter'), MAX_DISPLAY_PAGES, get_request_var('page'), $rows, $total_rows, 8, __('RRD Files'), 'page', 'main');
 
 	form_start('rrdcleaner.php');
 
@@ -553,6 +553,8 @@ function filter() {
 					$('#text').text('Rebuilding RRDfile Listing');
 					pulsate('#text');
 					$.get('rrdcleaner.php?header=false&rescan=1&clear=1', function(data) {
+						checkForLogout(data);
+
 						$('#main').html(data);
 						$('#text').text('Finished').fadeOut(2000);
 						applySkin();
@@ -563,6 +565,8 @@ function filter() {
 					$('#text').text('Scheduling Archiving of All Unknowns');
 					pulsate('#text');
 					$.get('rrdcleaner.php?header=false&action=arcall&raction=3&clear=1', function(data) {
+						checkForLogout(data);
+
 						$('#main').html(data);
 						$('#text').text('Finished').fadeOut(2000);
 						applySkin();
@@ -573,6 +577,8 @@ function filter() {
 					$('#text').text('Scheduling Purging of All Unknowns');
 					pulsate('#text');
 					$.get('rrdcleaner.php?header=false&action=remall&raction=1&clear=1', function(data) {
+						checkForLogout(data);
+
 						$('#main').html(data);
 						$('#text').text('Finished').fadeOut(2000);
 						applySkin();
